﻿//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APN504X
// Target Platform : Windows, .NET Framework, C++
// Date            : August 2017
// Version         : 1.0
//*****************************************************************************
#include "file.h"
#include "local_define.h"
using namespace System;
using namespace System::IO;


//#########################################################################
//  Name      : file_write_header
//  Function  : write header to the text file
//  Arguments :
//      in pName    : file name
//      in now_time : actual measurement time(msec)
//      in in_cps   : pointer to the array of input count rate(cps)
//      in th_cps   : pointer to the array of throughput count rate(cps)
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_header(String ^pName, unsigned int now_time,
                      unsigned int *in_cps, unsigned int *th_cps)
{
    try {
        // open file(create)
        StreamWriter ^writer = File::CreateText(pName);

        // write header information
        try {
            writer->WriteLine("[header]");
            writer->WriteLine("Real time(s), {0}", now_time/1000);
            writer->WriteLine("Input rate(cps), {0},{1},{2},{3}", *in_cps, *(in_cps+1), *(in_cps+2), *(in_cps+3));
            writer->WriteLine("Throughput rate(cps), {0},{1},{2},{3}", *th_cps, *(th_cps+1), *(th_cps+2), *(th_cps+3));
        }
        finally
        {
            if (writer) {
                delete (IDisposable^)writer;
            }
        }

    }
    catch (Exception ^e) {
        // failed to open file
        return(-1);
    }

    return(0);
}


//#########################################################################
//  Name      : file_write_data
//  Function  : write data to the text file
//  Arguments :
//      in pName : file name
//      in chnum : number of CHs
//      in pBuff : array of data
//  Return :
//       0 : success
//      -1 : failed to open file
//#########################################################################
int file_write_data(String ^pName, int chnum, unsigned int pBuff[][NUM_DATA])
{
    int i, j;

    try {
        // open file(append)
        StreamWriter ^writer = File::AppendText(pName);

        // write data
        try {
            writer->WriteLine("[data]");
            for (i = 0; i < NUM_DATA; i++) {
                writer->Write("{0}", pBuff[0][i]);      // CH1
				for (j = 1; j < chnum; j++) {
                    writer->Write(",{0}", pBuff[j][i]); // CH2-
				}
                writer->WriteLine();
            }
        }
        finally
        {
            if (writer) {
                delete (IDisposable^)writer;
            }
        }
    }
    catch (Exception ^e) {
        // failed to open file
        return(-1);
    }

    return(i);
}
